package core.engine.terrain;

import core.engine.Loader;
import core.engine.entity.Entity;
import core.engine.model.HexagonModel;
import core.engine.model.RawModel;
import core.engine.model.TexturedModel;
import core.engine.textures.ModelTexture;
import utils.vectors.Vector3f;

import java.util.ArrayList;
import java.util.List;

public class Terrain {


    private final List<TerrainTile> terrainTiles;

    private Terrain(List<TerrainTile> terrainTiles) {
        this.terrainTiles = terrainTiles;
    }

    public static Terrain generateTerrain(Loader loader) {
        HexagonModel hexagonModel = new HexagonModel();
        RawModel hexagonRawModel = loader.loadToVAO(hexagonModel.getVertices(), hexagonModel.getTextureCoords(), hexagonModel.getNormals(), hexagonModel.getIndices());
        ModelTexture hexagonTexture = new ModelTexture(loader.loadTexture("white"));
        TexturedModel hexagontexturedModel = new TexturedModel(hexagonRawModel, hexagonTexture);

        TerrainTile terrainTile = new TerrainTile(hexagontexturedModel, new Vector3f(1.3f,0,0.68f), 0,0,0,0.075f);
        List<TerrainTile> generatedTerrainTiles = new ArrayList<>();
        generatedTerrainTiles.add(terrainTile);

        return new Terrain(generatedTerrainTiles);
    }

    public List<TerrainTile> getTerrainTiles() {
        return terrainTiles;
    }
}
